@@ -77,8 +77,6 @@ MHD_state_to_string (enum MHD_CONNECTION_STATE state)
       return "footers sent";
     case MHD_CONNECTION_CLOSED:
       return "closed";
-    case MHD_TLS_CONNECTION_INIT:
-      return "secure connection init";
     default:
       return "unrecognized connection state";
     }
@@ -174,7 +172,7 @@ MHD_http_unescape (char *val)
  *
  * @param kind header kind to pass to @a cb
  * @param connection connection to add headers to
- * @param[in|out] args argument URI string (after "?" in URI),
+ * @param[in,out] args argument URI string (after "?" in URI),
  *        clobbered in the process!
  * @param cb function to call on each key-value pair found
  * @param[out] num_headers set to the number of headers found
